==> warzone2100_2.2.2+dfsg1.orig.tar.gz: warzone2100-2.2.2.orig/src/message_parser.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TEXT_T = 258,
     QTEXT_T = 259,
     NULL_T = 260,
     VIEW_T_RES = 261,
     VIEW_T_RPL = 262,
     VIEW_T_PROX = 263,
     VIEW_T_RPLX = 264,
     VIEW_T_BEACON = 265,
     IMD_NAME_T = 266,
     IMD_NAME2_T = 267,
     SEQUENCE_NAME_T = 268,
     AUDIO_NAME_T = 269
   };
#endif
/* Tokens.  */
#define TEXT_T 258
#define QTEXT_T 259
#define NULL_T 260
#define VIEW_T_RES 261
#define VIEW_T_RPL 262
#define VIEW_T_PROX 263
#define VIEW_T_RPLX 264
#define VIEW_T_BEACON 265
#define IMD_NAME_T 266
#define IMD_NAME2_T 267
#define SEQUENCE_NAME_T 268
#define AUDIO_NAME_T 269




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 94 "message_parser.y"
{
	char*                   sval;
	struct VIEWDATAMESSAGE* viewdatamsg;
	struct TEXT_MESSAGE*    txtmsg;
	VIEW_TYPE               viewtype;
	VIEW_RESEARCH*          researchdata;
	struct
	{
		const char**    stringArray;
		unsigned int    count;
	}                       msg_list;
}
/* Line 1489 of yacc.c.  */
#line 90 "message_parser.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE message_lval;

==> warzone2100_2.3.8.orig.tar.gz: warzone2100-2.3.8/src/message_parser.tab.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TEXT_T = 258,
     QTEXT_T = 259,
     NULL_T = 260,
     VIEW_T_RES = 261,
     VIEW_T_RPL = 262,
     VIEW_T_PROX = 263,
     VIEW_T_RPLX = 264,
     VIEW_T_BEACON = 265,
     IMD_NAME_T = 266,
     IMD_NAME2_T = 267,
     SEQUENCE_NAME_T = 268,
     AUDIO_NAME_T = 269
   };
#endif
/* Tokens.  */
#define TEXT_T 258
#define QTEXT_T 259
#define NULL_T 260
#define VIEW_T_RES 261
#define VIEW_T_RPL 262
#define VIEW_T_PROX 263
#define VIEW_T_RPLX 264
#define VIEW_T_BEACON 265
#define IMD_NAME_T 266
#define IMD_NAME2_T 267
#define SEQUENCE_NAME_T 268
#define AUDIO_NAME_T 269




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 94 "message_parser.y"

	char*                   sval;
	struct VIEWDATAMESSAGE* viewdatamsg;
	struct TEXT_MESSAGE*    txtmsg;
	VIEW_TYPE               viewtype;
	VIEW_RESEARCH*          researchdata;
	struct
	{
		const char**    stringArray;
		unsigned int    count;
	}                       msg_list;



/* Line 1676 of yacc.c  */
#line 95 "message_parser.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE message_lval;
